import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:vaycore/dartin.dart';
import 'package:vaycore/mvvm/base_page.dart';
import 'package:vaycore/mvvm/base_provider.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-12
///

/// 页面的基类 [BasePageProvider]
///
/// 隐藏了 [Provider] 的调用
abstract class BasePageProvider<T extends BaseProvider> extends BasePage {
  final T mProvider;

  /// 构造函数
  ///
  /// [params] 代表注入ViewModel[mProvider]时所需的参数，需按照[mProvider]的构造方法顺序赋值
  BasePageProvider({List<dynamic> params})
      : mProvider = inject<T>(params: params);

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider<T>.value(
      value: mProvider,
      child: super.build(context),
    );
  }
}
